@@ -52,7 +52,6 @@ class Button(BaseInput):
     """
 
     template = "%s/layout/button.html"
-    field_classes = "tbxforms-button"
 
     @classmethod
     def primary(cls, name, value, disabled=False, css_class="", **kwargs):
@@ -61,7 +60,9 @@ class Button(BaseInput):
             name,
             value,
             disabled=disabled,
-            css_class=f"{css_class} tbxforms-button--primary",
+            css_class=(
+                f"{css_class} tbxforms-button tbxforms-button--primary"
+            ),
             **kwargs,
         )
 
@@ -72,7 +73,9 @@ class Button(BaseInput):
             name,
             value,
             disabled=disabled,
-            css_class=f"{css_class} tbxforms-button--secondary",
+            css_class=(
+                f"{css_class} tbxforms-button tbxforms-button--secondary"
+            ),
             **kwargs,
         )
 
@@ -83,7 +86,9 @@ class Button(BaseInput):
             name,
             value,
             disabled=disabled,
-            css_class=f"{css_class} tbxforms-button--warning",
+            css_class=(
+                f"{css_class} tbxforms-button tbxforms-button--warning"
+            ),
             **kwargs,
         )
 
@@ -98,6 +103,6 @@ class Button(BaseInput):
 class Submit(BaseInput):
     def __init__(self, name, value, disabled=False, css_class="", **kwargs):
         raise NotImplementedError(
-            "'Submit' is not used in TBX forms in favour of a 'Button'. "
-            "See 'project_styleguide.forms.ExampleForm' for usage."
+            "'Submit' is not used in tbxforms in favour of a 'Button'. "
+            "See README for an example."
         )
